controllers

package
v0.0.0-...-c107b7b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 8, 2016 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CampaignController

type CampaignController struct {
	rbac.CommonController
}

func (*CampaignController) Add

func (this *CampaignController) Add()

@router /add [*]

func (*CampaignController) Edit

func (this *CampaignController) Edit()

@router /edit [*]

func (*CampaignController) GetAllGroups

func (this *CampaignController) GetAllGroups()

@router /loadGroups [*]

func (*CampaignController) GetCampaignReport

func (this *CampaignController) GetCampaignReport()

@router /getCampaignReport [get]

func (*CampaignController) GetCategoryByParentId

func (this *CampaignController) GetCategoryByParentId()

@router /getCategoryByParentId [get]

func (*CampaignController) GetPmpLovs

func (this *CampaignController) GetPmpLovs() map[string][]models.PmpLov

func (*CampaignController) Index

func (this *CampaignController) Index()

@router /index [get]

func (*CampaignController) NewCampaignCreative

func (this *CampaignController) NewCampaignCreative()

@router /newCreative [*]

func (*CampaignController) Upload

func (this *CampaignController) Upload()

@router /upload [*]

type DemandVo

type DemandVo struct {
	Name              string
	DemandAdspaceId   int
	Proportion        int
	Day1              int
	Day2              int
	Day3              int
	Day4              int
	Day5              int
	Day6              int
	Day7              int
	Operation         string
	DemandAdspaceName string
	AdspaceId         int
}

type DspRequest

type DspRequest struct {
	Dimension int       `form:"dimension"`
	Date      time.Time `form:"date"`
	QueryStr  string    `form:"q"`
}

type FlightGroupSummaryRequest

type FlightGroupSummaryRequest struct {
	Page   int    `form:"page"`
	Rows   int    `form:"rows"`
	Sortby string `form:"sort"`
	Order  string `form:"order"`

	AdvertiserId string `form:"advertiserId`
	GroupId      string `form:"groupId`
}

type LoanRequestController

type LoanRequestController struct {
	rbac.CommonController
}

func (*LoanRequestController) Prepare

func (this *LoanRequestController) Prepare()

@router /prepare [get]

type LtvAppController

type LtvAppController struct {
	beego.Controller
}

oprations for LtvApp

func (*LtvAppController) Delete

func (c *LtvAppController) Delete()

@Title Delete @Description delete the LtvApp @Param id path string true "The id you want to delete" @Success 200 {string} delete success! @Failure 403 id is empty @router /:id [delete]

func (*LtvAppController) GetAll

func (c *LtvAppController) GetAll()

@Title Get All @Description get LtvApp @Param query query string false "Filter. e.g. col1:v1,col2:v2 ..." @Param fields query string false "Fields returned. e.g. col1,col2 ..." @Param sortby query string false "Sorted-by fields. e.g. col1,col2 ..." @Param order query string false "Order corresponding to each sortby field, if single value, apply to all sortby fields. e.g. desc,asc ..." @Param limit query string false "Limit the size of result set. Must be an integer" @Param offset query string false "Start position of result set. Must be an integer" @Success 200 {object} models.LtvApp @Failure 403 @router / [get]

func (*LtvAppController) GetOne

func (c *LtvAppController) GetOne()

@Title Get @Description get LtvApp by id @Param id path string true "The key for staticblock" @Success 200 {object} models.LtvApp @Failure 403 :id is empty @router /:id [get]

func (*LtvAppController) Post

func (c *LtvAppController) Post()

@Title Post @Description create LtvApp @Param body body models.LtvApp true "body for LtvApp content" @Success 200 {int} models.LtvApp.Id @Failure 403 body is empty @router / [post]

func (*LtvAppController) Put

func (c *LtvAppController) Put()

@Title Update @Description update the LtvApp @Param id path string true "The id you want to update" @Param body body models.LtvApp true "body for LtvApp content" @Success 200 {object} models.LtvApp @Failure 403 :id is not int @router /:id [put]

func (*LtvAppController) URLMapping

func (c *LtvAppController) URLMapping()

type LtvDashboardController

type LtvDashboardController struct {
	rbac.CommonController
}

func (*LtvDashboardController) GetTop5Campaign

func (c *LtvDashboardController) GetTop5Campaign()

@router /GetTop5Campaign [get]

func (*LtvDashboardController) GetTop5Channel

func (c *LtvDashboardController) GetTop5Channel()

@router /GetTop5Channel [get]

type LtvFlightController

type LtvFlightController struct {
	beego.Controller
}

oprations for LtvFlight

func (*LtvFlightController) Delete

func (c *LtvFlightController) Delete()

@Title Delete @Description delete the LtvFlight @Param id path string true "The id you want to delete" @Success 200 {string} delete success! @Failure 403 id is empty @router /:id [delete]

func (*LtvFlightController) GetAll

func (c *LtvFlightController) GetAll()

@Title Get All @Description get LtvFlight @Param query query string false "Filter. e.g. col1:v1,col2:v2 ..." @Param fields query string false "Fields returned. e.g. col1,col2 ..." @Param sortby query string false "Sorted-by fields. e.g. col1,col2 ..." @Param order query string false "Order corresponding to each sortby field, if single value, apply to all sortby fields. e.g. desc,asc ..." @Param limit query string false "Limit the size of result set. Must be an integer" @Param offset query string false "Start position of result set. Must be an integer" @Success 200 {object} models.LtvFlight @Failure 403 @router / [get]

func (*LtvFlightController) GetOne

func (c *LtvFlightController) GetOne()

@Title Get @Description get LtvFlight by id @Param id path string true "The key for staticblock" @Success 200 {object} models.LtvFlight @Failure 403 :id is empty @router /:id [get]

func (*LtvFlightController) Post

func (c *LtvFlightController) Post()

@Title Post @Description create LtvFlight @Param body body models.LtvFlight true "body for LtvFlight content" @Success 200 {int} models.LtvFlight.Id @Failure 403 body is empty @router / [post]

func (*LtvFlightController) Put

func (c *LtvFlightController) Put()

@Title Update @Description update the LtvFlight @Param id path string true "The id you want to update" @Param body body models.LtvFlight true "body for LtvFlight content" @Success 200 {object} models.LtvFlight @Failure 403 :id is not int @router /:id [put]

func (*LtvFlightController) URLMapping

func (c *LtvFlightController) URLMapping()

type LtvFlightGroupController

type LtvFlightGroupController struct {
	rbac.CommonController
}

oprations for LtvFlightGroup

func (*LtvFlightGroupController) Create

func (c *LtvFlightGroupController) Create()

~~~~~~~~~~~~~ below are custom methods ~~~~~~~~~~~~~~~ // @router /create [get]

func (*LtvFlightGroupController) Delete

func (c *LtvFlightGroupController) Delete()

@Title Delete @Description delete the LtvFlightGroup @Param id path string true "The id you want to delete" @Success 200 {string} delete success! @Failure 403 id is empty @router /:id [delete]

func (*LtvFlightGroupController) Detail

func (c *LtvFlightGroupController) Detail()

@router /Detail/:id [get]

func (*LtvFlightGroupController) Edit

func (c *LtvFlightGroupController) Edit()

@router /Edit/:id [get]

func (*LtvFlightGroupController) FullReportPage

func (c *LtvFlightGroupController) FullReportPage()

@router /fullReport/:id [get]

func (*LtvFlightGroupController) FullReportPageAll

func (c *LtvFlightGroupController) FullReportPageAll()

@router /fullReport [get]

func (*LtvFlightGroupController) GetAll

func (c *LtvFlightGroupController) GetAll()

@Title Get All @Description get LtvFlightGroup @Param query query string false "Filter. e.g. col1:v1,col2:v2 ..." @Param fields query string false "Fields returned. e.g. col1,col2 ..." @Param sortby query string false "Sorted-by fields. e.g. col1,col2 ..." @Param order query string false "Order corresponding to each sortby field, if single value, apply to all sortby fields. e.g. desc,asc ..." @Param limit query string false "Limit the size of result set. Must be an integer" @Param offset query string false "Start position of result set. Must be an integer" @Success 200 {object} models.LtvFlightGroup @Failure 403 @router / [get]

func (*LtvFlightGroupController) GetOne

func (c *LtvFlightGroupController) GetOne()

@Title Get @Description get LtvFlightGroup by id @Param id path string true "The key for staticblock" @Success 200 {object} models.LtvFlightGroup @Failure 403 :id is empty @router /:id [get]

func (*LtvFlightGroupController) GetSummaryList

func (c *LtvFlightGroupController) GetSummaryList()

@Title Delete @Description delete the LtvFlightGroup @Param advertiserId path string true "The advertiser id you want to query" @Param groupId path string true "The flight group id you want to query" @Success 200 {string} get the summary list sucessfully! @Failure 403 failed to get query @router /GetSummaryList [get]

func (*LtvFlightGroupController) Post

func (c *LtvFlightGroupController) Post()

@Title Post @Description create LtvFlightGroup @Param body body models.LtvFlightGroup true "body for LtvFlightGroup content" @Success 200 {int} models.LtvFlightGroup.Id @Failure 403 body is empty @router / [post]

func (*LtvFlightGroupController) Put

func (c *LtvFlightGroupController) Put()

@Title Update @Description update the LtvFlightGroup @Param id path string true "The id you want to update" @Param body body models.LtvFlightGroup true "body for LtvFlightGroup content" @Success 200 {object} models.LtvFlightGroup @Failure 403 :id is not int @router /:id [put]

func (*LtvFlightGroupController) Save

func (c *LtvFlightGroupController) Save()

@router /Save [post]

func (*LtvFlightGroupController) URLMapping

func (c *LtvFlightGroupController) URLMapping()

type MainController

type MainController struct {
	beego.Controller
}

func (*MainController) Get

func (this *MainController) Get()

type MediaVo

type MediaVo struct {
	Id   int
	Text string
}

type PerformanceController

type PerformanceController struct {
	rbac.CommonController
}

func (*PerformanceController) Get

func (this *PerformanceController) Get()

type PmpAdspaceController

type PmpAdspaceController struct {
	rbac.CommonController
}

oprations for PmpAdspace

func (*PmpAdspaceController) Delete

func (c *PmpAdspaceController) Delete()

@Title Delete @Description delete the PmpAdspace @Param id path string true "The id you want to delete" @Success 200 {string} delete success! @Failure 403 id is empty @router /:id [delete]

func (*PmpAdspaceController) GetAdspaceList

func (this *PmpAdspaceController) GetAdspaceList()

get adspace list by page

func (*PmpAdspaceController) GetAll

func (c *PmpAdspaceController) GetAll()

@Title Get All @Description get PmpAdspace @Param query query string false "Filter. e.g. col1:v1,col2:v2 ..." @Param fields query string false "Fields returned. e.g. col1,col2 ..." @Param sortby query string false "Sorted-by fields. e.g. col1,col2 ..." @Param order query string false "Order corresponding to each sortby field, if single value, apply to all sortby fields. e.g. desc,asc ..." @Param limit query string false "Limit the size of result set. Must be an integer" @Param offset query string false "Start position of result set. Must be an integer" @Success 200 {object} models.PmpAdspace @Failure 403 @router / [get]

func (*PmpAdspaceController) GetOne

func (c *PmpAdspaceController) GetOne()

@Title Get @Description get PmpAdspace by id @Param id path string true "The key for staticblock" @Success 200 {object} models.PmpAdspace @Failure 403 :id is empty @router /:id [get]

func (*PmpAdspaceController) Post

func (c *PmpAdspaceController) Post()

@Title Post @Description create PmpAdspace @Param body body models.PmpAdspace true "body for PmpAdspace content" @Success 200 {int} models.PmpAdspace.Id @Failure 403 body is empty @router / [post]

func (*PmpAdspaceController) Put

func (c *PmpAdspaceController) Put()

@Title Update @Description update the PmpAdspace @Param id path string true "The id you want to update" @Param body body models.PmpAdspace true "body for PmpAdspace content" @Success 200 {object} models.PmpAdspace @Failure 403 :id is not int @router /:id [put]

func (*PmpAdspaceController) SaveOrUpdateAdspace

func (c *PmpAdspaceController) SaveOrUpdateAdspace()

save or update adspace with param models.AdspaceVo

func (*PmpAdspaceController) URLMapping

func (c *PmpAdspaceController) URLMapping()

type PmpAdspaceMatrixController

type PmpAdspaceMatrixController struct {
	beego.Controller
}

oprations for PmpAdspaceMatrix

func (*PmpAdspaceMatrixController) Delete

func (c *PmpAdspaceMatrixController) Delete()

@Title Delete @Description delete the PmpAdspaceMatrix @Param id path string true "The id you want to delete" @Success 200 {string} delete success! @Failure 403 id is empty @router /:id [delete]

func (*PmpAdspaceMatrixController) DeleteByDemandIdAndAdspaceId

func (c *PmpAdspaceMatrixController) DeleteByDemandIdAndAdspaceId()

delete mapping relation by demand id and adspace id

func (*PmpAdspaceMatrixController) GetAll

func (c *PmpAdspaceMatrixController) GetAll()

@Title Get All @Description get PmpAdspaceMatrix @Param query query string false "Filter. e.g. col1:v1,col2:v2 ..." @Param fields query string false "Fields returned. e.g. col1,col2 ..." @Param sortby query string false "Sorted-by fields. e.g. col1,col2 ..." @Param order query string false "Order corresponding to each sortby field, if single value, apply to all sortby fields. e.g. desc,asc ..." @Param limit query string false "Limit the size of result set. Must be an integer" @Param offset query string false "Start position of result set. Must be an integer" @Success 200 {object} models.PmpAdspaceMatrix @Failure 403 @router / [get]

func (*PmpAdspaceMatrixController) GetOne

func (c *PmpAdspaceMatrixController) GetOne()

@Title Get @Description get PmpAdspaceMatrix by id @Param id path string true "The key for staticblock" @Success 200 {object} models.PmpAdspaceMatrix @Failure 403 :id is empty @router /:id [get]

func (*PmpAdspaceMatrixController) Post

func (c *PmpAdspaceMatrixController) Post()

@Title Post @Description create PmpAdspaceMatrix @Param body body models.PmpAdspaceMatrix true "body for PmpAdspaceMatrix content" @Success 200 {int} models.PmpAdspaceMatrix.Id @Failure 403 body is empty @router / [post]

func (*PmpAdspaceMatrixController) Put

func (c *PmpAdspaceMatrixController) Put()

@Title Update @Description update the PmpAdspaceMatrix @Param id path string true "The id you want to update" @Param body body models.PmpAdspaceMatrix true "body for PmpAdspaceMatrix content" @Success 200 {object} models.PmpAdspaceMatrix @Failure 403 :id is not int @router /:id [put]

func (*PmpAdspaceMatrixController) URLMapping

func (c *PmpAdspaceMatrixController) URLMapping()

func (*PmpAdspaceMatrixController) UpdateAdspaceMatrix

func (c *PmpAdspaceMatrixController) UpdateAdspaceMatrix()

Update demand & adspace maps

type PmpDemandAdspaceController

type PmpDemandAdspaceController struct {
	rbac.CommonController
}

oprations for PmpDemandAdspace

func (*PmpDemandAdspaceController) Delete

func (c *PmpDemandAdspaceController) Delete()

@Title Delete @Description delete the PmpDemandAdspace @Param id path string true "The id you want to delete" @Success 200 {string} delete success! @Failure 403 id is empty @router /:id [delete]

func (*PmpDemandAdspaceController) GetAll

func (c *PmpDemandAdspaceController) GetAll()

@Title Get All @Description get PmpDemandAdspace @Param query query string false "Filter. e.g. col1:v1,col2:v2 ..." @Param fields query string false "Fields returned. e.g. col1,col2 ..." @Param sortby query string false "Sorted-by fields. e.g. col1,col2 ..." @Param order query string false "Order corresponding to each sortby field, if single value, apply to all sortby fields. e.g. desc,asc ..." @Param limit query string false "Limit the size of result set. Must be an integer" @Param offset query string false "Start position of result set. Must be an integer" @Success 200 {object} models.PmpDemandAdspace @Failure 403 @router / [get]

func (*PmpDemandAdspaceController) GetDemandAdspaceListByDemand

func (c *PmpDemandAdspaceController) GetDemandAdspaceListByDemand()

get demand adspace list by demand id

func (*PmpDemandAdspaceController) GetOne

func (c *PmpDemandAdspaceController) GetOne()

@Title Get @Description get PmpDemandAdspace by id @Param id path string true "The key for staticblock" @Success 200 {object} models.PmpDemandAdspace @Failure 403 :id is empty @router /:id [get]

func (*PmpDemandAdspaceController) Put

func (c *PmpDemandAdspaceController) Put()

@Title Update @Description update the PmpDemandAdspace @Param id path string true "The id you want to update" @Param body body models.PmpDemandAdspace true "body for PmpDemandAdspace content" @Success 200 {object} models.PmpDemandAdspace @Failure 403 :id is not int @router /:id [put]

func (*PmpDemandAdspaceController) SaveOrUpdateDemandAdspace

func (c *PmpDemandAdspaceController) SaveOrUpdateDemandAdspace()

save or update adspace with param models.DemandAdspaceVo

func (*PmpDemandAdspaceController) URLMapping

func (c *PmpDemandAdspaceController) URLMapping()

type PmpDemandPlatformDeskController

type PmpDemandPlatformDeskController struct {
	rbac.CommonController
}

oprations for PmpDemandPlatformDesk

func (*PmpDemandPlatformDeskController) Delete

func (c *PmpDemandPlatformDeskController) Delete()

@Title Delete @Description delete the PmpDemandPlatformDesk @Param id path string true "The id you want to delete" @Success 200 {string} delete success! @Failure 403 id is empty @router /:id [delete]

func (*PmpDemandPlatformDeskController) GetAll

func (c *PmpDemandPlatformDeskController) GetAll()

@Title Get All @Description get PmpDemandPlatformDesk @Param query query string false "Filter. e.g. col1:v1,col2:v2 ..." @Param fields query string false "Fields returned. e.g. col1,col2 ..." @Param sortby query string false "Sorted-by fields. e.g. col1,col2 ..." @Param order query string false "Order corresponding to each sortby field, if single value, apply to all sortby fields. e.g. desc,asc ..." @Param limit query string false "Limit the size of result set. Must be an integer" @Param offset query string false "Start position of result set. Must be an integer" @Success 200 {object} models.PmpDemandPlatformDesk @Failure 403 @router / [get]

func (*PmpDemandPlatformDeskController) GetDemandByAdspace

func (c *PmpDemandPlatformDeskController) GetDemandByAdspace()

Get demands by adspace id

func (*PmpDemandPlatformDeskController) GetDemandList

func (this *PmpDemandPlatformDeskController) GetDemandList()

Get the demand list

func (*PmpDemandPlatformDeskController) GetDemandsMappingInfo

func (c *PmpDemandPlatformDeskController) GetDemandsMappingInfo()

get the all the demands information to map to a specified adspace

func (*PmpDemandPlatformDeskController) GetOne

func (c *PmpDemandPlatformDeskController) GetOne()

@Title Get @Description get PmpDemandPlatformDesk by id @Param id path string true "The key for staticblock" @Success 200 {object} models.PmpDemandPlatformDesk @Failure 403 :id is empty @router /:id [get]

func (*PmpDemandPlatformDeskController) Post

@Title Post @Description create PmpDemandPlatformDesk @Param body body models.PmpDemandPlatformDesk true "body for PmpDemandPlatformDesk content" @Success 200 {int} models.PmpDemandPlatformDesk.Id @Failure 403 body is empty @router / [post]

func (*PmpDemandPlatformDeskController) Put

@Title Update @Description update the PmpDemandPlatformDesk @Param id path string true "The id you want to update" @Param body body models.PmpDemandPlatformDesk true "body for PmpDemandPlatformDesk content" @Success 200 {object} models.PmpDemandPlatformDesk @Failure 403 :id is not int @router /:id [put]

func (*PmpDemandPlatformDeskController) SaveOrUpdateDemand

func (c *PmpDemandPlatformDeskController) SaveOrUpdateDemand()

save or upate demand

func (*PmpDemandPlatformDeskController) URLMapping

func (c *PmpDemandPlatformDeskController) URLMapping()

func (*PmpDemandPlatformDeskController) UpdateDailyAllocation

func (this *PmpDemandPlatformDeskController) UpdateDailyAllocation()

type PmpMediaController

type PmpMediaController struct {
	rbac.CommonController
}

oprations for PmpMedia

func (*PmpMediaController) Delete

func (c *PmpMediaController) Delete()

@Title Delete @Description delete the PmpMedia @Param id path string true "The id you want to delete" @Success 200 {string} delete success! @Failure 403 id is empty @router /:id [delete]

func (*PmpMediaController) GetAll

func (c *PmpMediaController) GetAll()

@Title Get All @Description get PmpMedia @Param query query string false "Filter. e.g. col1:v1,col2:v2 ..." @Param fields query string false "Fields returned. e.g. col1,col2 ..." @Param sortby query string false "Sorted-by fields. e.g. col1,col2 ..." @Param order query string false "Order corresponding to each sortby field, if single value, apply to all sortby fields. e.g. desc,asc ..." @Param limit query string false "Limit the size of result set. Must be an integer" @Param offset query string false "Start position of result set. Must be an integer" @Success 200 {object} models.PmpMedia @Failure 403 @router / [get]

func (*PmpMediaController) GetMediaList

func (this *PmpMediaController) GetMediaList()

Get the media list

func (*PmpMediaController) GetOne

func (c *PmpMediaController) GetOne()

@Title Get @Description get PmpMedia by id @Param id path string true "The key for staticblock" @Success 200 {object} models.PmpMedia @Failure 403 :id is empty @router /:id [get]

func (*PmpMediaController) Post

func (c *PmpMediaController) Post()

@Title Post @Description create PmpMedia @Param body body models.PmpMedia true "body for PmpMedia content" @Success 200 {int} models.PmpMedia.Id @Failure 403 body is empty @router / [post]

func (*PmpMediaController) Put

func (c *PmpMediaController) Put()

@Title Update @Description update the PmpMedia @Param id path string true "The id you want to update" @Param body body models.PmpMedia true "body for PmpMedia content" @Success 200 {object} models.PmpMedia @Failure 403 :id is not int @router /:id [put]

func (*PmpMediaController) SaveOrUpdateMedia

func (c *PmpMediaController) SaveOrUpdateMedia()

save or update media

func (*PmpMediaController) URLMapping

func (c *PmpMediaController) URLMapping()

type ReportController

type ReportController struct {
	rbac.CommonController
}

func (*ReportController) GetPdbDspReport

func (this *ReportController) GetPdbDspReport()

func (*ReportController) GetPdbDspReportData

func (this *ReportController) GetPdbDspReportData()

func (*ReportController) GetPdbMediaReport

func (this *ReportController) GetPdbMediaReport()

func (*ReportController) GetPdbMediaReportData

func (this *ReportController) GetPdbMediaReportData()

type ReportQueryRequest

type ReportQueryRequest struct {
	Dimension []string `form:"dimension[]"`
	Medias    []string `form:"media[]"`

	StartDate time.Time `form:"startDate,2006-1-2"`
	EndDate   time.Time `form:"endDate,2006-1-2"`
	Page      int       `form:"page"`
	Rows      int       `form:"rows"`
	Sortby    string    `form:"sortby"`
	Order     string    `form:"order"`
}

Jump to